@@ -1,6 +1,7 @@
-#' Format a URL for a specific article in a specific PLoS journal. 
-#' 
-#' @importFrom stringr str_replace
+#' Format a URL for a specific article in a specific PLoS journal.
+#'
+#' @export
+#' @keywords internal
 #' @param doi digital object identifier for an article in PLoS Journals
 #' @param journal quoted journal name (character)
 #' @return Get url for the article to use in your browser, etc.
@@ -9,21 +10,19 @@
 #'    PLoSBiology, PLoSGenetics, PLoSComputationalBiology, PLoSMedicine,
 #'	  PLoSONE, PLoSNeglectedTropicalDiseases, or PLoSPathogens.
 #' @examples \dontrun{
-#' formatarticleurl("10.1371/journal.pone.0004045", 'PLoSONE')
+#' formatarticleurl(doi="10.1371/journal.pone.0004045", journal='PLoSONE')
 #' }
-#' @export
-#' @keywords internal
-formatarticleurl <- function(doi, journal) 
+formatarticleurl <- function(doi, journal)
 {
   journalUrls <- c(  # string with all journal base url's
     PLoSBiology = 'http://www.plosbiology.org',
-    PLoSGenetics = 'http://www.plosgenetics.org', 
+    PLoSGenetics = 'http://www.plosgenetics.org',
     PLoSComputationalBiology = 'http://www.ploscompbiol.org',
 	  PLoSMedicine = 'http://www.plosmedicine.org',
 	  PLoSONE = 'http://www.plosone.org',
 	  PLoSNeglectedTropicalDiseases = 'http://www.plosntds.org',
 	  PLoSPathogens = 'http://www.plospathogens.org'
   )
-  paste(journalUrls[journal], '/article/info%3Adoi%2F', 
-    str_replace(doi, '/', '%2F'), sep="")
-}
\ No newline at end of file
+  paste(journalUrls[journal], '/article/info%3Adoi%2F',
+    gsub('/', '%2F', doi), sep="")
+}
