@@ -1,5 +1,5 @@
 #' Get short keys for journals to use in searching specific journals.
-#' 
+#'
 #' @import XML httr
 #' @return Journals name keys.
 #' @export
@@ -8,10 +8,10 @@
 #' }
 journalnamekey <- function()
 {
-  names <- 
+  names <-
     content(GET(
-      "http://api.plos.org/search/?q=*:*&rows=0&fl=id,cross_published_journal_key&facet=true&facet.field=cross_published_journal_key&wt=json"
+      paste0(pbase(), "?q=*:*&rows=0&fl=id,cross_published_journal_key&facet=true&facet.field=cross_published_journal_key&wt=json")
     ))
   temp <- names$facet_counts$facet_fields[[1]][sapply(names$facet_counts$facet_fields[[1]], is.character)]
   do.call(c, temp)
-}
\ No newline at end of file
+}
